summaryrefslogtreecommitdiffstats
path: root/src/include/ipxe/tls.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/ipxe/tls.h')
-rw-r--r--src/include/ipxe/tls.h14
1 files changed, 11 insertions, 3 deletions
diff --git a/src/include/ipxe/tls.h b/src/include/ipxe/tls.h
index 8d4e709d..804e1a1f 100644
--- a/src/include/ipxe/tls.h
+++ b/src/include/ipxe/tls.h
@@ -99,8 +99,8 @@ enum tls_tx_pending {
TLS_TX_FINISHED = 0x0010,
};
-/** A TLS cipher specification */
-struct tls_cipherspec {
+/** A TLS cipher suite */
+struct tls_cipher_suite {
/** Public-key encryption algorithm */
struct pubkey_algorithm *pubkey;
/** Bulk encryption cipher algorithm */
@@ -108,7 +108,15 @@ struct tls_cipherspec {
/** MAC digest algorithm */
struct digest_algorithm *digest;
/** Key length */
- size_t key_len;
+ uint16_t key_len;
+ /** Numeric code (in network-endian order) */
+ uint16_t code;
+};
+
+/** A TLS cipher specification */
+struct tls_cipherspec {
+ /** Cipher suite */
+ struct tls_cipher_suite *suite;
/** Dynamically-allocated storage */
void *dynamic;
/** Public key encryption context */